@@ -1,6 +1,6 @@
 """Utilities for working with SR document instances."""
 from enum import Enum
-from typing import List, Optional, Union
+from typing import Iterator, List, Optional, Union
 
 from pydicom.dataset import Dataset
 from pydicom.sr.coding import Code
@@ -117,3 +117,28 @@ def find_content_items(
         relationship_type=relationship_type,
         recursive=recursive
     )
+
+
+def iter_roi_groups(dataset: Dataset) -> Iterator[Dataset]:
+    pass
+
+
+def get_coded_name(item: Dataset) -> CodedConcept:
+    name = item.ConceptNameCodeSequence[0]
+    return CodedConcept(
+        value=name.CodeValue,
+        scheme_designator=name.CodingSchemeDesignator,
+        meaning=name.CodeMeaning,
+        scheme_version=name.get('CodingSchemeVersion', None)
+    )
+
+
+def get_coded_value(item: Dataset) -> CodedConcept:
+    # TODO
+    value = item.ConceptCodeSequence[0]
+    return CodedConcept(
+        value=value.CodeValue,
+        scheme_designator=value.CodingSchemeDesignator,
+        meaning=value.CodeMeaning,
+        scheme_version=value.get('CodingSchemeVersion', None)
+    )
